==> bizext.php5.3_5.6.zip: bizext/lib/spout/Common/Exception/EncodingConversionException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPnK3GdgIwhPzqxRNMPFNZ2aGabm+7XJ/32UHGhoNDJTng+0MuyVMXlHgEiF4P+grOJuTXiHK
F+YV0WvV9rN7uu9RzVUKsFWoY/ikBa6d3s1X2qjfBWN14H27PQGqSQ2xGuZLCadXic3l8BvIcn1W
hMvjzW9j8j1h5j817qmrI8ee0G3hqFCE0ZQSaYZ6ehwFCJFAhxDs+m3l2iIYiMUjNrFkXbtCPVL9
2UGGCpjP4mi660yLPbSoVWuMqha6lN3EOZ7bLPgn8hCYkqUPpX4oCEN09xze8MtnFezpsFZL3QDU
Zasd2wF8qdVXsH3TgJICNegMfbIVtFfMzYBcVdEu7SPHsysS8gST8L5rEbFlIq8q5UbwZFMggaS2
XiBb6eQsgndgkIchma3MJn+fVGeSjEaqjNoDvn+wrWp1wY1mqwZSWmt3D6c5i267WOeg6Heb5SNp
CXEN26fZkas5JUuXSnFAQoRdell/79bLECT5hhvqKUi/edPCVQCkInj0ChFiR13onNOcEnLJmoED
BIX/O7kvcZ3BuIfYJtj9u0embQJx3kEwW62gbRqBmo3iKXtX9mlhNB0gI4kMM20gOfbfkONEfx95
q08gYbn+GL161doJJwdwL1i03xjcFlocmU3/407KVKu+Yz6ReICiddzylEd8AfWE6tIKu0YgkoNC
bVgHXJ9ml0psQcQcvJJlj9Fn+bDFfhcpxGiCAFfFYUdbO6X0Bhf7VUFKZjF84OIz2mAySV6yFJXY
a0TytgAIBawmDP+TyW3K0HKdib6iqh8ZnX2Et7Qe7Qdpw4HjLLfgscQ9pmRZGSwH3RhZK+4m+R2w
cwCp

==> bizext.php7.1.zip: bizext/lib/spout/Common/Exception/EncodingConversionException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPnB4Iwv38h21hd7UZIRPLM4soR/Lo1RaEy2/tC7mC2kW0yWAvOC1XtM/rqb6PeXKX1fji6EN
sQs3WS5A8A126pkAYB6Th960isISSQao9FZudm4t3VMAY+DQ4ILOSG3dYL8eGHRD4n/guDScoXZR
r4kmxK7lAyiebgn5YjuGynBv74LZcnBbwzmIpwNQ6kA8+RvGH8aMRavwkxbIghopQ1xDv2ysaFSU
NvCt7NhFdxGGSTgb5YDG7hYJMik+GyUMgUew4u1uczoL/79nY8IBj5FWUYAYpC5vbc6UJ2BKM10Q
LpMrbNlOdmH29A7grEhSS6UVDAu8kZfNLKd2iZGezbdgvQufznddXO6Tw8RbVOwh5WiEmBepwqiW
0NdK9PpICj2ib/28HzKUbLM3iF7xIii8Vqlb1Ui3FLn616MV7cEB5WUY62r8DhMeSbmUdpgXnRKE
UoiGp8Gtnfe5+jIliV9A4lqhp+/hSKsTtOwvnsBOrfbw8ItWES7hso5eNXjkZJrNywEKcELBRmxg
G05bI/y79npwu9rvEs+4MTvdBjwoV2rlVWYZsxj88l3T+uGd9xspM42RY1SdxvR8oQhU9lguwJhh
3aali7iYb7gxgUq9BLFggvWV0Mx9VS3yDE3mIJNtsfShzioitDqpLGP8W2Doj8XeUIGm+DzOAXsI
ziyOI4i+fi0vOXQR954oPVxhctDn+Xg78tBlFX9w7TepXEu2sBMriIFXVNYyS7Dy1QfnII9IoPrv
g5wP2ek7fB975iecNNQKTRII3fjkEwnQ1WBkSM2IsT+7GKfT5AuhEqw9b6hISnnM8wh/3fiqnau4
8uZIAbkYhNh3eWeGnWQ5yXwvdw18z0UKmd7Dl2pOCDfm2dA0qPvJrbWbrwx30cwZOoM9zZ3XZGYr
USaJggNDox8hQqF82+sNkW+xReK=
